==> digikam_3.5.0.orig.tar.bz2: digikam-3.5.0/extra/kipi-plugins/jalbumexport/kipiplugin_jalbumexport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=jAlbumExport
Name=jAlbumExport
Name[ca]=Exportador a jAlbum
Name[cs]=jAlbumExport
Name[da]=jAlbumExport
Name[de]=jAlbum-Export
Name[el]=jAlbumExport
Name[es]=Exportar a jAlbum
Name[fr]=Exportation « jAlbum »
Name[gl]=jAlbumExport
Name[hu]=jAlbum exportálás
Name[is]=jAlbum-útflutningur
Name[it]=jAlbumExport
Name[nl]=jAlbum-export
Name[pl]=jAlbumExport
Name[pt]=jAlbumExport
Name[pt_BR]=jAlbumExport
Name[sl]=jAlbumExport
Name[sv]=Export till jAlbum
Name[uk]=Експорт до jAlbum
Name[x-test]=xxjAlbumExportxx
Name[zh_TW]=jAlbum 匯出
Comment=A tool to pass selected photos to jAlbum
Comment[ca]=Una eina per passar les fotografies seleccionades a jAlbum
Comment[da]=Et værktøj til at sende udvalgte fotos til jAlbum
Comment[el]=Εργαλείο για να περαστούν επιλεγμένες φωτογραφίες στο jAlbum
Comment[es]=Una herramienta para transferir las fotos seleccionados a jAlbum
Comment[fr]=Un outil pour envoyer les images sélectionnées vers jAlbum
Comment[gl]=Ferramenta para enviar as imaxes seleccionadas a jAlbum.
Comment[hu]=Egy eszköz a kijelölt fényképek átadásához a jAlbumba
Comment[is]=Verkfæri til að senda myndir á jAlbum
Comment[it]=Uno strumento per esportare le foto selezionate a jAlbum
Comment[nl]=Een hulpmiddel om geselecteerde foto's aan jAlbum te overhandigen
Comment[pl]=Narzędzie do przesyłania wybranych zdjęć do jAlbum
Comment[pt]=Uma ferramenta para passar as fotografias seleccionadas para o jAlbum
Comment[pt_BR]=Ferramenta de envio das fotos selecionadas para o jAlbum
Comment[sl]=Orodje za premestitev izbranih fotografij v jAlbum
Comment[sv]=Ett verktyg för att skicka markerade foton till jAlbum
Comment[uk]=Інструмент для передавання позначених фотографій до jAlbum
Comment[x-test]=xxA tool to pass selected photos to jAlbumxx
Comment[zh_TW]=匯出選取的相片到 jAlbum 的工具
Type=Service
Icon=kipi-jalbum
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_jalbumexport
author=Andrew Goodbody, ajg zero two at elfringham dot co dot uk
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=

==> digikam_4.0.0.orig.tar.bz2: digikam-4.0.0/extra/kipi-plugins/jalbumexport/kipiplugin_jalbumexport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=jAlbumExport
Name=jAlbumExport
Name[bs]=jAlbumExport
Name[ca]=Exportador a jAlbum
Name[ca@valencia]=Exportador a jAlbum
Name[cs]=jAlbumExport
Name[da]=jAlbumExport
Name[de]=jAlbum-Export
Name[el]=jAlbumExport
Name[es]=Exportar a jAlbum
Name[fr]=Exportation « jAlbum »
Name[gl]=jAlbumExport
Name[hu]=jAlbum exportálás
Name[is]=jAlbum-útflutningur
Name[it]=jAlbumExport
Name[nb]=JAlbumEksport
Name[nl]=jAlbum-export
Name[pl]=jAlbumExport
Name[pt]=jAlbumExport
Name[pt_BR]=jAlbumExport
Name[sk]=jAlbumExport
Name[sl]=jAlbumExport
Name[sv]=Export till jAlbum
Name[tr]=jAlbumExport
Name[uk]=Експорт до jAlbum
Name[x-test]=xxjAlbumExportxx
Name[zh_TW]=jAlbum 匯出
Comment=A tool to pass selected photos to jAlbum
Comment[bs]=Alat za proslijeđivanje odabranih fotografija JAlbum-u
Comment[ca]=Una eina per passar les fotografies seleccionades a jAlbum
Comment[ca@valencia]=Una eina per passar les fotografies seleccionades a jAlbum
Comment[cs]=Nástroj pro poslání vybraných fotografií do jAlbum
Comment[da]=Et værktøj til at sende udvalgte fotos til jAlbum
Comment[de]=Ein Werkzeug, um ausgewählte Bilder zu jAlbum zu senden
Comment[el]=Εργαλείο για να περαστούν επιλεγμένες φωτογραφίες στο jAlbum
Comment[es]=Una herramienta para transferir las fotos seleccionados a jAlbum
Comment[fr]=Un outil pour envoyer les images sélectionnées vers jAlbum
Comment[gl]=Ferramenta para enviar as imaxes seleccionadas a jAlbum.
Comment[hu]=Egy eszköz a kijelölt fényképek átadásához a jAlbumba
Comment[is]=Verkfæri til að senda myndir á jAlbum
Comment[it]=Uno strumento per esportare le foto selezionate a jAlbum
Comment[nb]=Et verktøy som sender utvalgte bilder til JAlbum
Comment[nl]=Een hulpmiddel om geselecteerde foto's aan jAlbum te overhandigen
Comment[pl]=Narzędzie do przesyłania wybranych zdjęć do jAlbum
Comment[pt]=Uma ferramenta para passar as fotografias seleccionadas para o jAlbum
Comment[pt_BR]=Ferramenta de envio das fotos selecionadas para o jAlbum
Comment[sk]=Nástroj na predanie vybraných fotiek do jAlbumu
Comment[sl]=Orodje za premestitev izbranih fotografij v jAlbum
Comment[sv]=Ett verktyg för att skicka markerade foton till jAlbum
Comment[tr]=Seçili fotoğrafları jAlbum'e göndermek için bir araç
Comment[uk]=Інструмент для передавання позначених фотографій до jAlbum
Comment[x-test]=xxA tool to pass selected photos to jAlbumxx
Comment[zh_TW]=匯出選取的相片到 jAlbum 的工具
Type=Service
Icon=kipi-jalbum
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_jalbumexport
author=Andrew Goodbody, ajg zero two at elfringham dot co dot uk
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=
